/**
 * Open SUIT - Simple User Interface Toolkit
 * 
 * Copyright (c) 2009 France Telecom, http://www.francetelecom.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.ow2.opensuit.samples.spring.ui;

import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletRequest;
import org.ow2.opensuit.core.error.LocalizedError;
import org.ow2.opensuit.samples.spring.service.PersonService;
import org.ow2.opensuit.samples.spring.to.PersonTO;
import org.springframework.context.ApplicationContext;
import org.springframework.web.context.WebApplicationContext;

/**
* @author Adrien Ruffie / Pierre Smeyers
* @author http://opensuit.ow2.org/
* @version 1.0
*/
public class PersonsUIBean
{

    private final List<PersonTO> personsTO = new ArrayList<PersonTO>();
    private PersonService personService;
    private final PersonTO personTO = new PersonTO();
    
    public PersonsUIBean()
    {
    }

    public void load(final HttpServletRequest request)
    {
    	this.personsTO.clear();
        
    	PersonService personService = getPersonService(request);
        
        if(this.personService != null){
        	this.personsTO.addAll(personService.getAllPersons());
        }
    }

    public String addPerson(final HttpServletRequest request)
        throws LocalizedError
    {
        final PersonService personService = this.getPersonService(request);
        if(personService != null)
        {
            if(personService.savePerson(this.personTO)){
                return "success";
            } else {
                return "error";
            }
        } else {
            throw new LocalizedError("service_technical", new Object[] {
                "Person Service Unavailable"
            });
        }
    }

    private PersonService serviceLocator(final HttpServletRequest request)
    {
        if(request == null){
            throw new IllegalArgumentException("Request parameter must not be null");
        }
        
        final Object attr = request.getSession().getServletContext().getAttribute(WebApplicationContext.ROOT_WEB_APPLICATION_CONTEXT_ATTRIBUTE);
        
        if(attr == null){
            return null;
        }
        
        if(attr instanceof RuntimeException){
            throw (RuntimeException)attr;
    	}
        
    	if(attr instanceof Error){
            throw (Error)attr;
        }
        
        if(!(attr instanceof WebApplicationContext)){
            throw new IllegalStateException((new StringBuilder("Root context attribute is not of type WebApplicationContext: ")).append(attr).toString());
        } else {
            return (PersonService)((ApplicationContext)attr).getBean("personService");
        }
    }

    private PersonService getPersonService(HttpServletRequest request)
    {
        if(this.personService == null){
            this.personService = serviceLocator(request);
        }
        return this.personService;
    }

    public List<PersonTO> getPersonsTO()
    {
        return this.personsTO;
    }

    public PersonTO getPersonTO()
    {
        return this.personTO;
    }


}
